==> application-boot-api-2.0.22-sources.jar: cn/com/duiba/application/boot/api/ApplicationBootApiConfiguration.java <==
package cn.com.duiba.application.boot.api;

import cn.com.duiba.application.boot.api.component.application.ApplicationCacheService;
import cn.com.duiba.application.boot.api.component.mappingmode.MappingModeConfiguration;
import cn.com.duiba.application.boot.api.component.oauth2.ApplicationBootOauth2Client;
import cn.com.duiba.application.boot.api.component.oauth2.ApplicationBootOauth2ClientForApi;
import cn.com.duiba.application.boot.api.component.oauth2.ApplicationBootOauthProperties;
import cn.com.duiba.application.boot.api.component.stream.CatStreamConfiguration;
import org.apache.http.client.HttpClient;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Import;
import org.springframework.http.client.HttpComponentsClientHttpRequestFactory;
import org.springframework.web.client.RestTemplate;

@EnableConfigurationProperties({
        ApplicationBootOauthProperties.class
})
@Import({
        MappingModeConfiguration.class,
        CatStreamConfiguration.class
})
public class ApplicationBootApiConfiguration {

    @Bean
    public ApplicationCacheService applicationCacheService(){
        return new ApplicationCacheService();
    }

    @Bean
    @ConditionalOnMissingBean
    public ApplicationBootOauth2Client applicationBootOauth2Client(){
        return new ApplicationBootOauth2ClientForApi();
    }

    @Bean
    public RestTemplate oauthRestTemplate(HttpClient httpClient) {
        HttpComponentsClientHttpRequestFactory httpRequestFactory = new HttpComponentsClientHttpRequestFactory();
        httpRequestFactory.setConnectionRequestTimeout(30000);
        httpRequestFactory.setConnectTimeout(30000);
        httpRequestFactory.setReadTimeout(10000);
        httpRequestFactory.setHttpClient(httpClient);
        return new RestTemplate(httpRequestFactory);
    }





}

==> application-boot-api-2.0.25-sources.jar: cn/com/duiba/application/boot/api/ApplicationBootApiConfiguration.java <==
package cn.com.duiba.application.boot.api;

import cn.com.duiba.application.boot.api.component.application.ApplicationCacheService;
import cn.com.duiba.application.boot.api.component.environment.RequestEnvironmentDecisionMaker;
import cn.com.duiba.application.boot.api.component.mappingmode.MappingModeConfiguration;
import cn.com.duiba.application.boot.api.component.oauth2.ApplicationBootOauth2Client;
import cn.com.duiba.application.boot.api.component.oauth2.ApplicationBootOauth2ClientForApi;
import cn.com.duiba.application.boot.api.component.oauth2.ApplicationBootOauthProperties;
import cn.com.duiba.application.boot.api.component.stream.CatStreamConfiguration;
import org.apache.http.client.HttpClient;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Import;
import org.springframework.http.client.HttpComponentsClientHttpRequestFactory;
import org.springframework.web.client.RestTemplate;

@EnableConfigurationProperties({
        ApplicationBootOauthProperties.class
})
@Import({
        MappingModeConfiguration.class,
        CatStreamConfiguration.class
})
public class ApplicationBootApiConfiguration {

    @Bean
    public ApplicationCacheService applicationCacheService(){
        return new ApplicationCacheService();
    }

    @Bean
    @ConditionalOnMissingBean
    public ApplicationBootOauth2Client applicationBootOauth2Client(){
        return new ApplicationBootOauth2ClientForApi();
    }

    @Bean
    public RestTemplate oauthRestTemplate(HttpClient httpClient) {
        HttpComponentsClientHttpRequestFactory httpRequestFactory = new HttpComponentsClientHttpRequestFactory();
        httpRequestFactory.setConnectionRequestTimeout(30000);
        httpRequestFactory.setConnectTimeout(30000);
        httpRequestFactory.setReadTimeout(10000);
        httpRequestFactory.setHttpClient(httpClient);
        return new RestTemplate(httpRequestFactory);
    }

    //允许用户自定义环境决定者行为
    @Bean
    @ConditionalOnMissingBean(RequestEnvironmentDecisionMaker.class)
    public RequestEnvironmentDecisionMaker requestEnvironmentDecisionMaker(){
        return new RequestEnvironmentDecisionMaker();
    }

}
